@@ -1,15 +1,15 @@
-/*
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*- *
  * gtksourcecompletionmodel.c
- * This file is part of gtksourcecompletion
+ * This file is part of GtkSourceView
  *
  * Copyright (C) 2009 - Jesse van den Kieboom <jessevdk@gnome.org>
  *
- * gtksourceview is free software; you can redistribute it and/or
+ * GtkSourceView is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
  *
- * gtksourceview is distributed in the hope that it will be useful,
+ * GtkSourceView is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
@@ -269,10 +269,10 @@ tree_model_get_value (GtkTreeModel *tree_model,
 			g_value_set_object (value, node->proposal);
 			break;
 		case GTK_SOURCE_COMPLETION_MODEL_COLUMN_LABEL:
-			g_value_set_string (value, gtk_source_completion_proposal_get_label (node->proposal));
+			g_value_take_string (value, gtk_source_completion_proposal_get_label (node->proposal));
 			break;
 		case GTK_SOURCE_COMPLETION_MODEL_COLUMN_MARKUP:
-			g_value_set_string (value, gtk_source_completion_proposal_get_markup (node->proposal));
+			g_value_take_string (value, gtk_source_completion_proposal_get_markup (node->proposal));
 			break;
 		case GTK_SOURCE_COMPLETION_MODEL_COLUMN_ICON:
 			if (node->proposal == NULL)
