@@ -1,16 +1,16 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*- */
 /* gtksourcecompletionproposal.c
- * This file is part of gtksourcecompletion
+ * This file is part of GtkSourceView
  *
  * Copyright (C) 2007 - 2009 Jesús Barbero Rodríguez <chuchiperriman@gmail.com>
  * Copyright (C) 2009 - Jesse van den Kieboom <jessevdk@gnome.org>
  *
- * gtksourceview is free software; you can redistribute it and/or
+ * GtkSourceView is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
  *
- * gtksourceview is distributed in the hope that it will be useful,
+ * GtkSourceView is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
@@ -43,6 +43,10 @@ enum
 
 static guint signals[NUM_SIGNALS] = {0,};
 
+typedef GtkSourceCompletionProposalIface GtkSourceCompletionProposalInterface;
+
+G_DEFINE_INTERFACE (GtkSourceCompletionProposal, gtk_source_completion_proposal, G_TYPE_OBJECT)
+
 static gchar *
 gtk_source_completion_proposal_get_label_default (GtkSourceCompletionProposal *proposal)
 {
@@ -87,7 +91,7 @@ gtk_source_completion_proposal_equal_default (GtkSourceCompletionProposal *propo
 }
 
 static void 
-gtk_source_completion_proposal_init (GtkSourceCompletionProposalIface *iface)
+gtk_source_completion_proposal_default_init (GtkSourceCompletionProposalIface *iface)
 {
 	static gboolean initialized = FALSE;
 	
@@ -125,39 +129,6 @@ gtk_source_completion_proposal_init (GtkSourceCompletionProposalIface *iface)
 	}
 }
 
-GType 
-gtk_source_completion_proposal_get_type ()
-{
-	static GType gtk_source_completion_proposal_type_id = 0;
-	
-	if (!gtk_source_completion_proposal_type_id)
-	{
-		static const GTypeInfo g_define_type_info =
-		{
-			sizeof (GtkSourceCompletionProposalIface),
-			(GBaseInitFunc) gtk_source_completion_proposal_init, 
-			NULL,
-			NULL,
-			NULL,
-			NULL,
-			0,
-			0,
-			NULL
-		};
-		
-		gtk_source_completion_proposal_type_id = 
-			g_type_register_static (G_TYPE_INTERFACE,
-						"GtkSourceCompletionProposal",
-						&g_define_type_info,
-						0);
-
-		g_type_interface_add_prerequisite (gtk_source_completion_proposal_type_id,
-		                                   G_TYPE_OBJECT);
-	}
-	
-	return gtk_source_completion_proposal_type_id;
-}
-
 /**
  * gtk_source_completion_proposal_get_label:
  * @proposal: a #GtkSourceCompletionProposal.
